@@ -73,39 +73,39 @@ def write_kafka_stream(stream: DataFrame, spark_job_conf: dict, output_name):
     if output_stream_conf.get('processing_time') is not None:
         stream \
             .writeStream \
+            .queryName(output_stream_conf['name']) \
             .format("kafka") \
             .options(**output_stream_conf['kafka_options']) \
             .trigger(processingTime=output_stream_conf['processing_time']) \
             .outputMode(output_stream_conf['mode']) \
-            .start() \
-            .awaitTermination()
+            .start()
     elif output_stream_conf.get('availableNow') is not None:
         stream \
             .writeStream \
+            .queryName(output_stream_conf['name']) \
             .format("kafka") \
             .options(**output_stream_conf['kafka_options']) \
             .trigger(availableNow=output_stream_conf['availableNow']) \
             .outputMode(output_stream_conf['mode']) \
-            .start() \
-            .awaitTermination()
+            .start()
     elif output_stream_conf.get("once") is not None:
-        print(f'You choose to write into kafka stream with trigger.once={output_stream_conf.get("once")}')
         stream \
             .writeStream \
+            .queryName(output_stream_conf['name']) \
+            .queryName(output_stream_conf['name']) \
             .format("kafka") \
             .options(**output_stream_conf['kafka_options']) \
             .trigger(once=output_stream_conf['once']) \
             .outputMode(output_stream_conf['mode']) \
-            .start() \
-            .awaitTermination()
+            .start()
     else:
         stream \
             .writeStream \
+            .queryName(output_stream_conf['name']) \
             .format("kafka") \
             .options(**output_stream_conf['kafka_options']) \
             .outputMode(output_stream_conf['mode']) \
-            .start() \
-            .awaitTermination()
+            .start()
 
 
 ######
@@ -165,9 +165,9 @@ def write_delta(spark_job_conf: dict, output_name: str, df: DataFrame):
         df
         .write
         .format("delta")
-        .mode(output_conf['delta_options']['mode'])
+        .mode(output_conf['mode'])
         .partitionBy(output_conf['delta_options']['partition_columns'])
-        .option("checkpointLocation", output_conf['delta_options']['checkpoint_location'])
+        .option("checkpointLocation", output_conf['checkpoint_location'])
         .save(output_conf['delta_options']['location'])
     )
 
@@ -180,7 +180,7 @@ def write_delta_no_partitioning(spark_job_conf: dict, output_name: str, df: Data
         .write
         .format("delta")
         .mode(output_conf['delta_options']['mode'])
-        .option("checkpointLocation", output_conf['delta_options']['checkpoint_location'])
+        .option("checkpointLocation", output_conf['checkpoint_location'])
         .save(output_conf['delta_options']['location'])
     )
 
@@ -197,7 +197,7 @@ def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame
             .outputMode(output_stream_conf['mode']) \
             .trigger(processingTime=output_stream_conf['processing_time']) \
             .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     elif output_stream_conf.get('availableNow') is not None:
         stream \
@@ -207,7 +207,7 @@ def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame
             .outputMode(output_stream_conf['mode']) \
             .trigger(availableNow=output_stream_conf.get('availableNow')) \
             .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     elif output_stream_conf.get('once') is not None:
         stream \
@@ -217,7 +217,7 @@ def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame
             .outputMode(output_stream_conf['mode']) \
             .trigger(once=output_stream_conf.get('once')) \
             .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     else:
         stream \
@@ -226,7 +226,7 @@ def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame
             .format("delta") \
             .outputMode(output_stream_conf['mode']) \
             .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
 
 
@@ -241,7 +241,7 @@ def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, s
             .format("delta") \
             .outputMode(output_stream_conf['mode']) \
             .trigger(processingTime=output_stream_conf['processing_time']) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     elif output_stream_conf.get('availableNow') is not None:
         stream \
@@ -250,7 +250,7 @@ def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, s
             .format("delta") \
             .outputMode(output_stream_conf['mode']) \
             .trigger(availableNow=output_stream_conf.get('availableNow')) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     elif output_stream_conf.get('once') is not None:
         stream \
@@ -259,7 +259,7 @@ def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, s
             .format("delta") \
             .outputMode(output_stream_conf['mode']) \
             .trigger(once=output_stream_conf.get('once')) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     else:
         stream \
@@ -267,7 +267,7 @@ def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, s
             .queryName(output_stream_conf['name']) \
             .format("delta") \
             .outputMode(output_stream_conf['mode']) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
 
 
@@ -282,7 +282,7 @@ def write_delta_stream_with_custom_fnc(spark_job_conf, output_name: str, stream:
             .outputMode(output_stream_conf['mode']) \
             .trigger(processingTime=output_stream_conf['processing_time']) \
             .foreachBatch(updater_function) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     elif output_stream_conf.get('availableNow') is not None:
         stream \
@@ -292,7 +292,7 @@ def write_delta_stream_with_custom_fnc(spark_job_conf, output_name: str, stream:
             .outputMode(output_stream_conf['mode']) \
             .trigger(availableNow=output_stream_conf['availableNow']) \
             .foreachBatch(updater_function) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     elif output_stream_conf.get('once') is not None:
         stream \
@@ -302,7 +302,7 @@ def write_delta_stream_with_custom_fnc(spark_job_conf, output_name: str, stream:
             .outputMode(output_stream_conf['mode']) \
             .trigger(once=output_stream_conf['once']) \
             .foreachBatch(updater_function) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
     else:
         stream \
@@ -311,7 +311,7 @@ def write_delta_stream_with_custom_fnc(spark_job_conf, output_name: str, stream:
             .format("delta") \
             .outputMode(output_stream_conf['mode']) \
             .foreachBatch(updater_function) \
-            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
             .start(output_stream_conf['delta_options']['location'])
 
 
